@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -278,17 +278,17 @@ sub _args {
 
     $data ||= (@data == 1) ? $data[0] : (@data) ? [ @data ] : undef;
     $args = scalar @args ? { @args } : {};
+    $args = { %{ $self || {} }, %{ $args || {} } };
     $data = delete $args->{data} if exists $args->{data};
 
-    my $encodes = exists $args->{encodes} ? $args->{encodes} : '';
-    $args->{_auto} = HTML::AutoTag->new( encodes => $encodes, indent => $args->{indent}, level => $args->{level}, sorted => 1 );
+    $args->{_auto} = HTML::AutoTag->new(
+        encodes => exists $args->{encodes} ? $args->{encodes} : '',
+        indent  => $args->{indent},
+        level   => $args->{level},
+        sorted  => $args->{sorted_attrs}
+    );
 
-    if ($self) {
-        return ( $self, $self->{data}, $args ) if $self->{is_cached};
-        $args = { %{ $self || {} }, %{ $args || {} } };
-        delete $args->{data};
-        $data = $self->{data} unless $data or $args->{file};
-    }
+    return ( $self, $self->{data}, $args ) if $self and $self->{is_cached};
 
     $data = Spreadsheet::HTML::File::Loader::parse( $args ) if $args->{file};
     $data = [ $data ] unless ref($data);
@@ -453,9 +453,10 @@ For most cases, C<portrait> and C<landscape> are all you need.
 
 =head1 PARAMETERS
 
-All methods/procedures accept the same named parameters.
-You do not have to specify C<data>, any bare array references
-will be collected and assigned to C<data>.
+All methods/procedures accept the same named parameters. All
+parameters are initally undefined.  You do not have to specify
+C<data>, any bare array references will be collected and assigned
+to C<data>.
 
 =head2 LITERAL PARAMETERS
 
@@ -626,6 +627,12 @@ C<-r0>, it could be considered as a dynamic parameter. Be
 careful not to prepend a dash to C<headings> ... only dynamic
 parameters use leading dashes.
 
+=item * C<sorted_attrs: 0 or 1>
+
+This is useful for ensuring that attributes within tags are
+rendered in alphabetical ordering, for consistancy. You will
+most likely never need this feature.
+
 =back
 
 =head2 DYNAMIC PARAMETERS
@@ -816,20 +823,30 @@ different file formats:
 
 =over 4
 
-=item * L<JSON>
+=item * L<Spreadsheet::Read>
 
-=item * L<YAML>
+Uses the following:
+
+=over 4
 
 =item * L<Text::CSV>
 
 =item * L<Text::CSV_XS>
 
-=item * L<HTML::TableExtract>
+=item * L<Text::CSV_PP>
 
 =item * L<Spreadsheet::ParseExcel>
 
 =back
 
+=item * L<JSON>
+
+=item * L<YAML>
+
+=item * L<HTML::TableExtract>
+
+=back
+
 The following are used by some presets to enhance
 their output, if installed:
 
