@@ -4,6 +4,7 @@ use warnings FATAL => 'all';
 
 use Spreadsheet::HTML;
 use Spreadsheet::HTML::Presets::Animate;
+use Spreadsheet::HTML::Presets::Beadwork;
 use Spreadsheet::HTML::Presets::Calculator;
 use Spreadsheet::HTML::Presets::Conway;
 use Spreadsheet::HTML::Presets::Chess;
@@ -354,150 +355,6 @@ sub chess {
     return $js . $table;
 }
 
-sub dk {
-    my $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
-
-my $tmpl = '
-..........................................
-..................1111111.................
-.................414141414................
-................11221112211...............
-...............1122221222211..............
-............221122233233222122............
-...........22211122312132211222...........
-...........22211122222222211222...........
-.........511122222221112222221115.........
-.......5511122222222222222222211155.......
-......511111222211111111111222111115......
-....5511111122212222222222212211111155....
-...511111111111222222222222211111111115...
-..11111511111112222222222222111111511111..
-..11111155111111122222222211111155111111..
-..11111115551111111111111111115551111111..
-..11111111555122211111111222155511111111..
-...111111111112222251152222211111111111...
-....1111111111121222552221211111111111....
-.....11111111111222255222211111111111.....
-........11111112122255222121111111........
-........51151522222522522222515115........
-.......5111151555552222555551511115.......
-......511111111522222222225111111115......
-.....51111111115252522525251111111115.....
-....5111111111115252521525111111111115....
-....5111111111151151511511511111111115....
-....5111111111111........1111111111115....
-.....11111111111..........11111111111.....
-.....1111111111............1111111111.....
-...21221112212..............21221112212...
-..252212222122..............221222212252..
-.252222222222................22222222225..
-..........................................
-';
-
-    my %map = (
-        '.' => '#FFFFFF',
-        1 => '#AA0000',
-        2 => '#FFAA55',
-        3 => '#FFFFFF',
-        4 => '#D50000',
-        5 => '#FF5500',
-    );
-
-    my (@cells);
-    my @lines = grep ! $_ =~ /^\s*$/, split /\n/, $tmpl;
-    my $total_rows = scalar @lines;
-    my $total_cols;
-    for my $row (0 .. $#lines) {
-        my @chars = split //, $lines[$row];
-        $total_cols ||= scalar @chars;
-        for my $col (0 .. $#chars) {
-            next unless my $color = $map{ $chars[$col] };
-            push @cells, ( 
-                "-r${row}c${col}" => {
-                    width  => 16,
-                    height => 8,
-                    style  => { 'background-color' => $color },
-                }
-            );
-        }
-    }
-
-    my @args = (
-        pinhead  => 0,
-        tgroups  => 0,
-        headless => 0,
-        matrix   => 1,
-        wrap     => 0,
-        fill     => join( 'x', $total_rows, $total_cols ),
-        @cells,
-        @_,
-    );
-
-    $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
-}
-
-sub shroom {
-    my $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
-
-my $tmpl = '
-.....111111.....
-...1122223311...
-..133222233331..
-.13222222233331.
-.13223333222331.
-1222333333222221
-1222333333223321
-1322333333233331
-1332233332233331
-1332222222223321
-1322111111112221
-.11133133133111.
-..133313313331..
-..133333333331..
-...1333333331...
-....11111111....
-';
-
-    my %map = (
-        '.' => 'white',
-        1 => 'black',
-        2 => 'green',
-        3 => 'white',
-    );
-
-    my (@cells);
-    my @lines = grep ! $_ =~ /^\s*$/, split /\n/, $tmpl;
-    my $total_rows = scalar @lines;
-    my $total_cols;
-    for my $row (0 .. $#lines) {
-        my @chars = split //, $lines[$row];
-        $total_cols ||= scalar @chars;
-        for my $col (0 .. $#chars) {
-            next unless my $color = $map{ $chars[$col] };
-            push @cells, ( 
-                "-r${row}c${col}" => {
-                    width  => 16,
-                    height => 8,
-                    style  => { 'background-color' => $color },
-                }
-            );
-        }
-    }
-
-    my @args = (
-        pinhead  => 0,
-        tgroups  => 0,
-        headless => 0,
-        matrix   => 1,
-        wrap     => 0,
-        fill     => join( 'x', $total_rows, $total_cols ),
-        @cells,
-        @_,
-    );
-
-    $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
-}
-
 sub _js_wrapper {
     my %args = @_;
 
@@ -600,9 +457,25 @@ Generates a static checkers game board (US).
 
 Generates a static chess game board.
 
-=item * C<dk( %params )>
+=back
 
-=item * C<shroom( %params )>
+=head1 MORE PRESETS
+
+=over 4
+
+=item *L<Spreadsheet::HTML::Presets::Animate>
+
+=item *L<Spreadsheet::HTML::Presets::Beadwork>
+
+=item *L<Spreadsheet::HTML::Presets::Calculator>
+
+=item *L<Spreadsheet::HTML::Presets::Conway>
+
+=item *L<Spreadsheet::HTML::Presets::Chess>
+
+=item *L<Spreadsheet::HTML::Presets::Handson>
+
+=item *L<Spreadsheet::HTML::Presets::Sudoku>
 
 =back
 
